@@ -1,18 +1,15 @@
 import Yi
 
--- Preamble
-import Yi.Prelude
-import Prelude ()
-
--- Import the desired UI as needed. 
+-- Import the desired UI as needed.
 -- Some are not complied in, so we import none here.
 
 -- import Yi.UI.Vty (start)
--- import Yi.UI.Cocoa (start)
 -- import Yi.UI.Pango (start)
 
+myConfig :: Config
 myConfig = defaultCuaConfig -- replace with defaultVimConfig or defaultCuaConfig
 
+defaultUIConfig :: UIConfig
 defaultUIConfig = configUI myConfig
 
 -- Change the below to your needs, following the explanation in comments. See
@@ -23,24 +20,23 @@ defaultUIConfig = configUI myConfig
 main :: IO ()
 main = yi $ myConfig
   {
-   
+
    -- Keymap Configuration
    defaultKm = defaultKm myConfig,
 
    -- UI Configuration
-   -- Override the default UI as such: 
+   -- Override the default UI as such:
    startFrontEnd = startFrontEnd myConfig,
                     -- Yi.UI.Vty.start -- for Vty
    -- (can be overridden at the command line)
    -- Options:
    configUI = defaultUIConfig
-     { 
+     {
        configFontSize = Nothing,
                         -- 'Just 10' for specifying the size.
        configTheme = configTheme defaultUIConfig,
                      -- darkBlueTheme  -- Change the color scheme here.
-       
-       configWindowFill = ' ' 
+
+       configWindowFill = ' '
      }
   }
-
