@@ -1,15 +1,10 @@
 {-# LANGUAGE ScopedTypeVariables #-}
-{-# LANGUAGE CPP #-}
 
 -- | Utilities for working with new Control.Exception
 module Control.Exc (ignoringException, printingException, orException)
 where
 
-#if defined(__GLASGOW_HASKELL__) && (__GLASGOW_HASKELL__ >= 706)
 import Prelude
-#else
-import Prelude hiding (catch)
-#endif
 import Control.Exception (catch, SomeException)
 
 -- | Execute IO (Maybe a) action replacing all exceptions with return value of Nothing.
@@ -18,7 +13,7 @@ ignoringException f = f `catch` ignore
   where ignore (_ :: SomeException) = return Nothing
 
 -- | Execute IO () action, replacing all exceptions with messages
-printingException :: [Char] -> IO a -> IO a
+printingException :: String -> IO a -> IO a
 printingException desc f = f `catch` handler
   where handler (err :: SomeException) = fail $ concat [desc, " failed: ", show err]
 
