@@ -4,11 +4,12 @@ module System.FriendlyPath
   , isAbsolute'
   ) where
 
-import Control.Applicative
-import System.FilePath
+import Control.Applicative     ((<$>))
+import System.CanonicalizePath (canonicalizePath)
+import System.Directory        (getHomeDirectory)
+import System.FilePath         (isAbsolute, normalise, pathSeparator)
 import System.PosixCompat.User (getUserEntryForName, homeDirectory)
-import System.CanonicalizePath
-import System.Directory hiding (canonicalizePath)
+
 
 -- canonicalizePath follows symlinks, and does not work if the directory does not exist.
 
@@ -16,25 +17,10 @@ import System.Directory hiding (canonicalizePath)
 userToCanonPath :: FilePath -> IO String
 userToCanonPath f = canonicalizePath =<< expandTilda f
 
-{-
-TODO: export or remove
--- | Make a path more user-friendly by replacing the home directory with tilda.
-recoverTilda :: FilePath -> IO String
-recoverTilda path = do
-  home <- getHomeDirectory
-  return $ if home `isPrefixOf` path
-    then "~" ++ drop (length home) path
-    else path
-
--- | Turn a path into its canonicalized, user-friendly version.
-canonicalizePath' :: FilePath -> IO String
-canonicalizePath' f = recoverTilda =<< canonicalizePath f
--}
-
 -- | Turn a user-friendly path into a computer-friendly path by expanding the leading tilda.
 expandTilda :: String -> IO FilePath
 expandTilda ('~':path)
-  | (null path) || (head path == pathSeparator) = (++ path) <$> getHomeDirectory
+  | null path || (head path == pathSeparator) = (++ path) <$> getHomeDirectory
   -- Home directory of another user, e.g. ~root/
   | otherwise = let username = takeWhile (/= pathSeparator) path
                     dirname = drop (length username) path
