@@ -1,51 +1,60 @@
 {-# LANGUAGE CPP #-}
--- Copyright (c) 2007,8 JP Bernardy
--- Copyright (c) 2004 Don Stewart - http://www.cse.unsw.edu.au/~dons
+{-# OPTIONS_HADDOCK show-extensions #-}
 
 -- |
--- Facade of the Yi library, for use by confguration file. Just re-exports
--- a bunch of modules.
+-- Module      :  Yi
+-- License     :  GPL-2
+-- Maintainer  :  yi-devel@googlegroups.com
+-- Stability   :  experimental
+-- Portability :  portable
+--
+-- Facade of the Yi library, for use by confguration file. Just
+-- re-exports a bunch of modules.
 --
 -- You should therefore:
---      import Yi
--- in your ~/.config/yi/ scripts
 --
+-- @     import Yi@
+--
+-- in your @~/.config/yi/yi.hs@.
 
 module Yi
   (
     module Data.Prototype, -- prototypes are mainly there for config; makes sense to export them.
     module Yi.Boot,
+    module Yi.Buffer,
     module Yi.Config,
+    module Yi.Config.Default,
     module Yi.Core,
     module Yi.Dired,
+    module Yi.Editor,
     module Yi.Eval,
     module Yi.File,
-    module Yi.Config.Default,
-    module Yi.Search,
-    module Yi.Style,
-    module Yi.Style.Library,
+    module Yi.Keymap,
+    module Yi.Keymap.Keys,
     module Yi.Misc,
     module Yi.Mode.Haskell,
     module Yi.Mode.IReader,
-#ifdef SCION
-    module Yi.Scion
-#endif
+    module Yi.Search,
+    module Yi.Style,
+    module Yi.Style.Library,
   ) where
 
 import Data.Prototype
 import Yi.Boot
+import Yi.Buffer
 import Yi.Config
+import Yi.Config.Default
 import Yi.Core
 import Yi.Dired
+import Yi.Editor
 import Yi.Eval
 import Yi.File
-import Yi.Config.Default
+import Yi.Keymap
+import Yi.Keymap.Keys
+import Yi.Misc
+import Yi.Mode.Haskell (ghciGet, ghciLoadBuffer,
+                        ghciSetProcessName, ghciSetProcessArgs)
+import Yi.Mode.IReader (ireaderMode, ireadMode)
 import Yi.Search
 import Yi.Style
-import Yi.Style.Library
-import Yi.Misc
-import Yi.Mode.Haskell (ghciGet, ghciLoadBuffer)
-import Yi.Mode.IReader (ireaderMode, ireadMode) 
-#ifdef SCION
-import Yi.Scion
-#endif
+import Yi.Style.Library
\ No newline at end of file
