@@ -1,20 +1,21 @@
--- Copyright (c) JP Bernardy 2008
 {-# LANGUAGE ScopedTypeVariables #-}
 
 module Yi.IncrementalParse (recoverWith, symbol, eof, lookNext, testNext,
                             State, P, Parser(..), AlexState (..), scanner) where
-import Parser.Incremental hiding (run)
-import Yi.Lexer.Alex (AlexState (..))
-import Yi.Prelude
-import Prelude ()
-import Yi.Syntax
+
+import           Parser.Incremental (Parser (..), Process, eof, evalL, evalR,
+                                     lookNext, mkProcess, pushEof, pushSyms,
+                                     recoverWith, symbol, testNext)
+
+import           Yi.Lexer.Alex      (AlexState (..))
+import           Yi.Syntax          (Scanner (..))
 
 type P s a = Parser s a
 
 type State st token result = (st, Process token result)
 
 scanner :: forall st token result. Parser token result -> Scanner st token -> Scanner (State st token result) result
-scanner parser input = Scanner 
+scanner parser input = Scanner
     {
       scanInit = (scanInit input, mkProcess parser),
       scanLooked = scanLooked input . fst,
@@ -28,6 +29,5 @@ scanner parser input = Scanner
         updateState0 :: Process token result -> [(st,token)] -> [(State st token result, result)]
         updateState0 _        [] = []
         updateState0 curState toks@((st,tok):rest) = ((st, curState), result) : updateState0 nextState rest
-            where nextState =       evalL $           pushSyms [tok]           $ curState
-                  result    = fst $ evalR $ pushEof $ pushSyms (fmap snd toks) $ curState
-
+            where nextState =       evalL $           pushSyms [tok]           curState
+                  result    = fst $ evalR $ pushEof $ pushSyms (fmap snd toks) curState
