@@ -1,23 +1,38 @@
-{-# LANGUAGE FlexibleInstances, TemplateHaskell, DeriveDataTypeable #-}
--- (C) Copyright 2009 Deniz Dogan
+{-# LANGUAGE DeriveDataTypeable #-}
+{-# LANGUAGE DeriveFoldable     #-}
+{-# LANGUAGE FlexibleInstances  #-}
+{-# OPTIONS_HADDOCK show-extensions #-}
+
+-- |
+-- Module      :  Yi.Syntax.JavaScript
+-- License     :  GPL-2
+-- Maintainer  :  yi-devel@googlegroups.com
+-- Stability   :  experimental
+-- Portability :  portable
+--
+-- Parser for the JavaScript language as described at
+-- <http://publications.lib.chalmers.se/records/fulltext/112284.pdf Dogan 2009>.
+--
+-- The mode using this parser can be found at "Yi.Mode.JavaScript".
 
 module Yi.Syntax.JavaScript where
 
-import Data.DeriveTH
-import Data.Data (Data)
-import qualified Data.Foldable
-import Data.Monoid (Endo(..), mempty)
-import Prelude (maybe)
-import Yi.Buffer.Basic (Point(..))
-import Yi.IncrementalParse (P, eof, symbol, recoverWith)
-import Yi.Lexer.Alex (Stroke, Tok(..), tokToSpan, tokFromT)
-import Yi.Lexer.JavaScript ( TT, Token(..), Reserved(..), Operator(..)
-                           , tokenToStyle, prefixOperators, infixOperators
-                           , postfixOperators )
-import Yi.Prelude hiding (error, Const)
-import Yi.Style (errorStyle, StyleName)
-import Yi.Syntax.Tree (IsTree(..), sepBy1, sepBy)
+import           Prelude hiding (elem,error,any,exp)
 
+import           Control.Applicative (Alternative ((<|>), many), Applicative ((<*), (<*>), pure), optional, (<$>))
+import           Data.Data           (Data)
+import           Data.Foldable       (Foldable (foldMap), any, elem, toList)
+import           Data.Monoid         (Endo (..), Monoid (mempty), (<>))
+import qualified Data.Text           as T (cons)
+import           Data.Typeable       (Typeable)
+import           Yi.Buffer.Basic     (Point (..))
+import           Yi.Debug            (trace)
+import           Yi.IncrementalParse (P, eof, recoverWith, symbol)
+import           Yi.Lexer.Alex       (Stroke, Tok (..), tokFromT, tokToSpan)
+import           Yi.Lexer.JavaScript
+import           Yi.String           (showT)
+import           Yi.Style            (StyleName, errorStyle)
+import           Yi.Syntax.Tree      (IsTree (..), sepBy, sepBy1)
 
 -- * Data types, classes and instances
 
@@ -48,25 +63,25 @@ data Statement t = FunDecl t t (Parameters t) (Block t)
                  | With t (ParExpr t) (Block t)
                  | Comm t
                  | Expr (Expr t) (Semicolon t)
-                   deriving (Show, Data, Typeable)
+                   deriving (Show, Data, Typeable, Foldable)
 
 data Parameters t = Parameters t (BList t) t
                   | ParErr t
-                    deriving (Show, Data, Typeable)
+                    deriving (Show, Data, Typeable, Foldable)
 
 data ParExpr t = ParExpr t (BList (Expr t)) t
                | ParExprErr t
-                 deriving (Show, Data, Typeable)
+                 deriving (Show, Data, Typeable, Foldable)
 
 data ForContent t = ForNormal t (Expr t) t (Expr t)
                   | ForIn t (Expr t)
                   | ForErr t
-                    deriving (Show, Data, Typeable)
+                    deriving (Show, Data, Typeable, Foldable)
 
 data Block t = Block t (BList (Statement t)) t
              | BlockOne (Statement t)
              | BlockErr t
-               deriving (Show, Data, Typeable)
+               deriving (Show, Data, Typeable, Foldable)
 
 -- | Represents either a variable name or a variable name assigned to an
 --   expression.  @AssBeg@ is a variable name /maybe/ followed by an assignment.
@@ -75,7 +90,7 @@ data Block t = Block t (BList (Statement t)) t
 data VarDecAss t = AssBeg t (Maybe (VarDecAss t))
                  | AssRst t (Expr t)
                  | AssErr t
-                   deriving (Show, Data, Typeable)
+                   deriving (Show, Data, Typeable, Foldable)
 
 data Expr t = ExprObj t (BList (KeyValue t)) t
             | ExprPrefix t (Expr t)
@@ -90,33 +105,24 @@ data Expr t = ExprObj t (BList (KeyValue t)) t
             | ExprArr t (Maybe (Array t)) t (Maybe (Expr t))
             | PostExpr t
             | ExprErr t
-              deriving (Show, Data, Typeable)
+              deriving (Show, Data, Typeable, Foldable)
 
 data Array t = ArrCont (Expr t) (Maybe (Array t))
              | ArrRest t (Array t) (Maybe (Array t))
              | ArrErr t
-               deriving (Show, Data, Typeable)
+               deriving (Show, Data, Typeable, Foldable)
 
 data KeyValue t = KeyValue t t (Expr t)
                 | KeyValueErr t
-                  deriving (Show, Data, Typeable)
+                  deriving (Show, Data, Typeable, Foldable)
 
-$(derive makeFoldable ''Statement)
-$(derive makeFoldable ''Parameters)
-$(derive makeFoldable ''ParExpr)
-$(derive makeFoldable ''ForContent)
-$(derive makeFoldable ''Block)
-$(derive makeFoldable ''VarDecAss)
-$(derive makeFoldable ''Expr)
-$(derive makeFoldable ''Array)
-$(derive makeFoldable ''KeyValue)
 
 instance IsTree Statement where
     subtrees (FunDecl _ _ _ x) = fromBlock x
     subtrees (While _ _ x) = fromBlock x
     subtrees (DoWhile _ x _ _ _) = fromBlock x
     subtrees (For _ _ _ _ _ x) = fromBlock x
-    subtrees (If _ _ x mb) = fromBlock x ++ maybe [] subtrees mb
+    subtrees (If _ _ x mb) = fromBlock x <> maybe [] subtrees mb
     subtrees (Else _ x) = fromBlock x
     subtrees (With _ _ x) = fromBlock x
     subtrees _ = []
@@ -283,11 +289,11 @@ instance Strokable (Array TT) where
 
 -- | Normal stroker.
 normal :: TT -> Endo [Stroke]
-normal x = one tokenToStroke x
+normal = one tokenToStroke
 
 -- | Error stroker.
 error :: TT -> Endo [Stroke]
-error x = one (modStroke errorStyle . tokenToStroke) x
+error = one (modStroke errorStyle . tokenToStroke)
 
 one :: (t -> a) -> t -> Endo [a]
 one f x = Endo (f x :)
@@ -295,7 +301,7 @@ one f x = Endo (f x :)
 -- | Given a new style and a stroke, return a stroke with the new style appended
 --   to the old one.
 modStroke :: StyleName -> Stroke -> Stroke
-modStroke style stroke = fmap (style <>) stroke
+modStroke style = fmap (style <>)
 
 
 -- * Stroking functions
@@ -304,7 +310,7 @@ modStroke style stroke = fmap (style <>) stroke
 --   stroke (@xs'@), returns normal strokes for @xs'@ if there were no errors.
 --   Otherwise returns error strokes for @xs'@.
 nError :: [TT] -> [TT] -> Endo [Stroke]
-nError xs xs' = foldMap (failStroker xs) xs'
+nError xs = foldMap (failStroker xs)
 
 -- | Given a list of @TT@, if any of them is an error, returns an error stroker,
 --   otherwise a normal stroker.  Using e.g. existentials, we could make this
@@ -319,7 +325,7 @@ tokenToStroke = fmap tokenToStyle . tokToSpan
 
 -- | The main stroking function.
 getStrokes :: Tree TT -> Point -> Point -> Point -> [Stroke]
-getStrokes t0 _point _begin _end = trace ("\n" ++ show t0) result
+getStrokes t0 _point _begin _end = trace ('\n' `T.cons` showT t0) result
     where
       result = appEndo (foldMap toStrokes t0) []
 
@@ -362,7 +368,7 @@ statement = FunDecl <$> res Function' <*> plzTok name <*> parameters <*> block
 --   TODO: function hello() var x; is not a valid program.
 block :: P TT (Block TT)
 block = Block    <$> spc '{' <*> many statement <*> plzSpc '}'
-    <|> BlockOne <$> hate 1 (statement)
+    <|> BlockOne <$> hate 1 statement
     <|> BlockErr <$> hate 2 (pure errorToken)
 
 -- | Parser for expressions which may be statements.  In reality, any expression
@@ -370,7 +376,7 @@ block = Block    <$> spc '{' <*> many statement <*> plzSpc '}'
 --   the massive performance loss which is introduced when allowing JavaScript
 --   objects to be valid statements.
 stmtExpr :: P TT (Expr TT)
-stmtExpr = ExprSimple <$> simpleTok <*> optional (opExpr)
+stmtExpr = ExprSimple <$> simpleTok <*> optional opExpr
        <|> ExprPrefix <$> preOp <*> plzExpr
        <|> ExprNew    <$> res New' <*> plz funCall
        <|> funCall
@@ -381,7 +387,7 @@ stmtExpr = ExprSimple <$> simpleTok <*> optional (opExpr)
        <|> ExprErr <$> hate 2 (symbol (const True))
     where
       funCall :: P TT (Expr TT)
-      funCall = ExprFunCall <$> name <*> parExpr <*> optional (opExpr)
+      funCall = ExprFunCall <$> name <*> parExpr <*> optional opExpr
 
 -- | The basic idea here is to parse "the rest" of expressions, e.g. @+ 3@ in @x
 --   + 3@ or @[i]@ in @x[i]@.  Anything which is useful in such a scenario goes
@@ -403,20 +409,20 @@ expression = ExprObj     <$> spc '{' <*> keyValue `sepBy` spc ',' <*> plzSpc '}'
       keyValue :: P TT (KeyValue TT)
       keyValue = KeyValue    <$> name <*> plzSpc ':' <*> plzExpr
              <|> KeyValueErr <$> hate 1 (symbol (const True))
-             <|> KeyValueErr <$> hate 2 (pure $ errorToken)
+             <|> KeyValueErr <$> hate 2 (pure errorToken)
 
 -- | Parses both empty and non-empty arrays.  Should probably be split up into
 --   further parts to allow for the separation of @[]@ and @[1, 2, 3]@.
 array :: P TT (Expr TT)
 array = ExprArr <$> spc '[' <*> optional arrayContents <*> plzSpc ']'
-                <*> optional (opExpr)
+                <*> optional opExpr
     where
       arrayContents :: P TT (Array TT)
       arrayContents = ArrCont <$> expression <*> optional arrRest
       arrRest :: P TT (Array TT)
       arrRest = ArrRest <$> spc ',' <*> (arrayContents
                                      <|> ArrErr <$> hate 1 (symbol (const True))
-                                     <|> ArrErr <$> hate 2 (pure $ errorToken))
+                                     <|> ArrErr <$> hate 2 (pure errorToken))
                                     <*> optional arrRest
 
 
@@ -552,7 +558,7 @@ anything = recoverWith (pure errorToken)
 
 -- | Weighted recovery.
 hate :: Int -> P s a -> P s a
-hate n x = power n recoverWith x
+hate n = power n recoverWith
     where
       power 0 _ = id
       power m f = f . power (m - 1) f
