@@ -1,8 +1,8 @@
 
 module Yi.UI.Batch (start) where
 
-import Yi.UI.Common
-import Yi.Config
+import Yi.Config    (UIBoot)
+import Yi.UI.Common (dummyUI)
 
 -- | Initialise the ui
 start :: UIBoot
@@ -11,4 +11,4 @@ start _cfg _ch _outCh _ed = do
                     "Are you sure you compiled with support for any real UI?",
                     "(for example, pass -fvty to cabal install)"]
     return dummyUI
-    
+
